@@ -1,6 +1,6 @@
 /* digits.h
  *
- * $Id: digits.h,v 1.3 1999/12/07 00:35:26 nisse Exp $ */
+ * $Id: digits.h,v 1.5 2001/03/14 18:21:23 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -56,7 +56,17 @@ base64_init(struct base64_state *state, UINT8 terminator);
 int
 base64_decode(struct base64_state *state, UINT8 c);
 
+struct lsh_string *
+decode_base64(UINT32 length, const UINT8 *in);
+
+
 /* Only used by the testsuite */
-struct lsh_string *simple_decode_hex(const unsigned char *in);
+struct lsh_string *
+simple_decode_hex(const unsigned char *in);
+
+#if 0
+struct lsh_string *
+simple_decode_base64(const unsigned char *in);
+#endif
 
 #endif /* LSH_DIGITS_H_INCLUDED */
