@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: keyexchange.h,v 1.48 2000/11/15 21:59:02 nisse Exp $ */
+ * $Id: keyexchange.h,v 1.50 2001/03/14 18:28:49 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -71,6 +71,7 @@
      (vars
        ;; FIXME: Add some method or attribute describing
        ;; the requirements on the hostkey algorithm.
+
        ; Algorithms is an array indexed by the KEX_* values above
        (init method void
 	     "struct ssh_connection *connection"
@@ -94,7 +95,7 @@
        (languages_client_to_server object int_list)
        (languages_server_to_client object int_list)
        (first_kex_packet_follows . int)
-       ;; Used may be NULL. Used only for sending.
+       ; May be NULL. Used only for sending.
        (first_kex_packet string)))
 */
      
@@ -114,20 +115,23 @@
 struct lsh_string *format_kex(struct kexinit *kex);
 void disconnect_kex_failed(struct ssh_connection *connection, const char *msg);
 
-struct crypto_instance *kex_make_encrypt(struct hash_instance *secret,
-					 struct object_list *algorithms,
-					 int type,
-					 struct lsh_string *session_id);
+struct crypto_instance *
+kex_make_encrypt(struct hash_instance *secret,
+		 struct object_list *algorithms,
+		 int type,
+		 struct lsh_string *session_id);
 
-struct crypto_instance *kex_make_decrypt(struct hash_instance *secret,
-					 struct object_list *algorithms,
-					 int type,
-					 struct lsh_string *session_id);
+struct crypto_instance *
+kex_make_decrypt(struct hash_instance *secret,
+		 struct object_list *algorithms,
+		 int type,
+		 struct lsh_string *session_id);
 
-struct mac_instance *kex_make_mac(struct hash_instance *secret,
-				  struct object_list *algorithms,
-				  int type,
-				  struct lsh_string *session_id);
+struct mac_instance *
+kex_make_mac(struct hash_instance *secret,
+	     struct object_list *algorithms,
+	     int type,
+	     struct lsh_string *session_id);
 
 struct make_kexinit *
 make_simple_kexinit(struct randomness *r,
@@ -153,10 +157,6 @@ make_newkeys_handler(struct crypto_instance *crypto,
 		     struct mac_instance *mac,
 		     struct compress_instance *compression);
 
-struct install_keys *
-make_install_new_keys(int is_server,
-		      struct object_list *algorithms);
-
 void
 keyexchange_finish(struct ssh_connection *connection,
 		   struct object_list *algorithms,
