@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: randomness.h,v 1.12 2000/11/14 20:07:17 nisse Exp $ */
+ * $Id: randomness.h,v 1.13 2000/11/26 23:25:58 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -53,8 +53,8 @@
    (class
      (name random_poll)
      (vars
-       ;; Both functions return an entropy estimate, and adds the
-       ;; randomness to the given hash instance.
+       ; Both functions return an entropy estimate, and adds the
+       ; randomness to the given hash instance.
        (slow method unsigned "struct hash_instance *")
        (fast method unsigned "struct hash_instance *")
        (background method void)))
