@@ -1,6 +1,6 @@
 /* server_keyexchange.c
  *
- * $Id: server_keyexchange.c,v 1.46 2000/10/31 22:33:28 nisse Exp $ */
+ * $Id: server_keyexchange.c,v 1.47 2001/02/25 22:38:20 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -67,7 +67,7 @@ do_handle_dh_init(struct packet_handler *c,
   CAST(dh_server, closure, c);
   int res;
   
-  trace("handle_dh_init()\n");
+  trace("handle_dh_init\n");
 
   res = dh_process_client_msg(&closure->dh, packet);
   lsh_string_free(packet);
