@@ -52,7 +52,7 @@ int main(int argc, char **argv)
   argp_parse(&werror_argp, argc, argv, 0, NULL, NULL);
 
 {
-  struct alist *algorithms = all_signature_algorithms(make_reasonably_random());
+  struct alist *algorithms = all_signature_algorithms(make_bad_random());
   struct sexp *key = string_to_sexp(SEXP_TRANSPORT, ssh_format("%lz", "{KDM6ZHNhKDE6cDEyODqD2afCziqRefQ82zv/594PDu8m3V365E1TG8DeRWNN"
  	      "LAfLkpsNvhDaWABw5qv7uEFcRL/1cLitd532U6rZfce964FdfogQPmFgbtPY"
  	      "opX7/TQNLUniIIM+us5VEeIsTwKX7TUemUj6hI6cj623tHvMR970JVteHV4Q"
@@ -76,6 +76,7 @@ int main(int argc, char **argv)
 
   sign = SIGN_SPKI(s, msg->length, msg->data);
 
+  
   v = SIGNER_GET_VERIFIER(s);
   if (!v)
     /* Can't create verifier */
